@@ -14,6 +14,7 @@
 #    under the License.
 
 import logging
+import queue
 import threading
 import time
 import uuid
@@ -21,7 +22,6 @@ import uuid
 import cachetools
 from oslo_utils import eventletutils
 from oslo_utils import timeutils
-from six import moves
 
 import oslo_messaging
 from oslo_messaging._drivers import amqp as rpc_amqp
@@ -48,7 +48,7 @@ class MessageOperationsHandler(object):
 
     def __init__(self, name):
         self.name = "%s (%s)" % (name, hex(id(self)))
-        self._tasks = moves.queue.Queue()
+        self._tasks = queue.Queue()
 
         self._shutdown = eventletutils.Event()
         self._shutdown_thread = threading.Thread(
@@ -75,7 +75,7 @@ class MessageOperationsHandler(object):
         while True:
             try:
                 task = self._tasks.get(block=False)
-            except moves.queue.Empty:
+            except queue.Empty:
                 break
             task()
 
@@ -292,6 +292,7 @@ class ObsoleteReplyQueuesCache(object):
 
 
 class AMQPListener(base.PollStyleListener):
+    use_cache = False
 
     def __init__(self, driver, conn):
         super(AMQPListener, self).__init__(driver.prefetch_size)
@@ -308,7 +309,13 @@ class AMQPListener(base.PollStyleListener):
 
     def __call__(self, message):
         ctxt = rpc_amqp.unpack_context(message)
-        unique_id = self.msg_id_cache.check_duplicate_message(message)
+        try:
+            unique_id = self.msg_id_cache.check_duplicate_message(message)
+        except rpc_common.DuplicateMessageError:
+            LOG.exception("ignoring duplicate message %s", ctxt.msg_id)
+            return
+        if self.use_cache:
+            self.msg_id_cache.add(unique_id)
         if ctxt.msg_id:
             LOG.debug("received message msg_id: %(msg_id)s reply to "
                       "%(queue)s", {'queue': ctxt.reply_q,
@@ -351,7 +358,7 @@ class AMQPListener(base.PollStyleListener):
                 self.conn.consume(timeout=min(self._current_timeout, left))
             except rpc_common.Timeout:
                 LOG.debug("AMQPListener connection timeout")
-                self._current_timeout = max(self._current_timeout * 2,
+                self._current_timeout = min(self._current_timeout * 2,
                                             ACK_REQUEUE_EVERY_SECONDS_MAX)
             else:
                 self._current_timeout = ACK_REQUEUE_EVERY_SECONDS_MIN
@@ -389,6 +396,7 @@ class AMQPListener(base.PollStyleListener):
 
 class RpcAMQPListener(AMQPListener):
     message_cls = AMQPIncomingMessage
+    use_cache = True
 
     def __call__(self, message):
         # NOTE(kgiusti): In the original RPC implementation the RPC server
@@ -431,7 +439,7 @@ class ReplyWaiters(object):
     def get(self, msg_id, timeout):
         try:
             return self._queues[msg_id].get(block=True, timeout=timeout)
-        except moves.queue.Empty:
+        except queue.Empty:
             raise oslo_messaging.MessagingTimeout(
                 'Timed out waiting for a reply '
                 'to message ID %s' % msg_id)
@@ -446,7 +454,7 @@ class ReplyWaiters(object):
             queue.put(message_data)
 
     def add(self, msg_id):
-        self._queues[msg_id] = moves.queue.Queue()
+        self._queues[msg_id] = queue.Queue()
         queues_length = len(self._queues)
         if queues_length > self._wrn_threshold:
             LOG.warning('Number of call queues is %(queues_length)s, '
@@ -490,7 +498,7 @@ class ReplyWaiter(object):
                 # ack every ACK_REQUEUE_EVERY_SECONDS_MAX seconds
                 self.conn.consume(timeout=current_timeout)
             except rpc_common.Timeout:
-                current_timeout = max(current_timeout * 2,
+                current_timeout = min(current_timeout * 2,
                                       ACK_REQUEUE_EVERY_SECONDS_MAX)
             except Exception:
                 LOG.exception("Failed to process incoming message, retrying..")
@@ -557,7 +565,7 @@ class ReplyWaiter(object):
                     timeout = cm_timeout
             try:
                 message = self.waiters.get(msg_id, timeout=timeout)
-            except moves.queue.Empty:
+            except queue.Empty:
                 self._raise_timeout_exception(msg_id)
 
             reply, ending = self._process_reply(message)
@@ -593,9 +601,10 @@ class AMQPDriverBase(base.BaseDriver):
     def _get_exchange(self, target):
         return target.exchange or self._default_exchange
 
-    def _get_connection(self, purpose=rpc_common.PURPOSE_SEND):
+    def _get_connection(self, purpose=rpc_common.PURPOSE_SEND, retry=None):
         return rpc_common.ConnectionContext(self._connection_pool,
-                                            purpose=purpose)
+                                            purpose=purpose,
+                                            retry=retry)
 
     def _get_reply_q(self):
         with self._reply_q_lock:
@@ -641,7 +650,7 @@ class AMQPDriverBase(base.BaseDriver):
             log_msg = "CAST unique_id: %s " % unique_id
 
         try:
-            with self._get_connection(rpc_common.PURPOSE_SEND) as conn:
+            with self._get_connection(rpc_common.PURPOSE_SEND, retry) as conn:
                 if notify:
                     exchange = self._get_exchange(target)
                     LOG.debug(log_msg + "NOTIFY exchange '%(exchange)s'"
