@@ -12,12 +12,12 @@
 #    under the License.
 
 import os
+import queue
 import time
 import uuid
 
 import fixtures
 from oslo_config import cfg
-from six import moves
 
 import oslo_messaging
 from oslo_messaging._drivers.kafka_driver import kafka_options
@@ -102,7 +102,7 @@ class RpcServerFixture(fixtures.Fixture):
         self.target = target
         self.endpoint = endpoint or TestServerEndpoint()
         self.executor = executor
-        self.syncq = moves.queue.Queue()
+        self.syncq = queue.Queue()
         self.ctrl_target = ctrl_target or self.target
 
     def setUp(self):
@@ -130,7 +130,7 @@ class RpcServerFixture(fixtures.Fixture):
     def _stop(self):
         self.thread.stop()
         self.thread.join(timeout=30)
-        if self.thread.isAlive():
+        if self.thread.is_alive():
             raise Exception("Server did not shutdown correctly")
 
     def ping(self, ctxt):
@@ -280,13 +280,13 @@ class IsValidDistributionOf(object):
 
     def match(self, actual):
         errors = InvalidDistribution(self.original, actual)
-        received = [[i for i in l] for l in actual]
+        received = [[idx for idx in act] for act in actual]
 
         def _remove(obj, lists):
-            for l in lists:
-                if obj in l:
-                    front = l[0]
-                    l.remove(obj)
+            for li in lists:
+                if obj in li:
+                    front = li[0]
+                    li.remove(obj)
                     return front
             return None
 
@@ -296,8 +296,8 @@ class IsValidDistributionOf(object):
                 errors.missing += item
             elif item != o:
                 errors.wrong_order.append([item, o])
-        for l in received:
-            errors.extra += l
+        for li in received:
+            errors.extra += li
         return errors or None
 
 
@@ -323,7 +323,7 @@ class NotificationFixture(fixtures.Fixture):
         self.conf = conf
         self.url = url
         self.topics = topics
-        self.events = moves.queue.Queue()
+        self.events = queue.Queue()
         self.name = str(id(self))
         self.batch = batch
 
@@ -356,7 +356,7 @@ class NotificationFixture(fixtures.Fixture):
     def _stop(self):
         self.thread.stop()
         self.thread.join(timeout=30)
-        if self.thread.isAlive():
+        if self.thread.is_alive():
             raise Exception("Server did not shutdown properly")
 
     def notifier(self, publisher, topics=None):
@@ -395,7 +395,7 @@ class NotificationFixture(fixtures.Fixture):
         try:
             while True:
                 results.append(self.events.get(timeout=timeout))
-        except moves.queue.Empty:
+        except queue.Empty:
             pass
         return results
 
