@@ -16,7 +16,6 @@
 import sys
 
 from oslo_serialization import jsonutils
-import six
 import testscenarios
 
 import oslo_messaging
@@ -25,8 +24,8 @@ from oslo_messaging.tests import utils as test_utils
 
 load_tests = testscenarios.load_tests_apply_scenarios
 
-EXCEPTIONS_MODULE = 'exceptions' if six.PY2 else 'builtins'
-OTHER_EXCEPTIONS_MODULE = 'builtins' if six.PY2 else 'exceptions'
+EXCEPTIONS_MODULE = 'builtins'
+OTHER_EXCEPTIONS_MODULE = 'exceptions'
 
 
 class NovaStyleException(Exception):
@@ -199,9 +198,9 @@ class DeserializeRemoteExceptionTestCase(test_utils.BaseTestCase):
               args=[],
               kwargs={},
               str=("Remote error: NovaStyleException test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               msg=("Remote error: NovaStyleException test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               remote_name='RemoteError',
               remote_args=(),
               remote_kwargs={'exc_type': 'NovaStyleException',
@@ -215,9 +214,9 @@ class DeserializeRemoteExceptionTestCase(test_utils.BaseTestCase):
               args=[],
               kwargs={},
               str=("Remote error: Exception test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               msg=("Remote error: Exception test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               remote_name='RemoteError',
               remote_args=(),
               remote_kwargs={'exc_type': 'Exception',
@@ -231,9 +230,9 @@ class DeserializeRemoteExceptionTestCase(test_utils.BaseTestCase):
               args=[],
               kwargs={},
               str=("Remote error: FarcicalError test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               msg=("Remote error: FarcicalError test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               remote_name='RemoteError',
               remote_args=(),
               remote_kwargs={'exc_type': 'FarcicalError',
@@ -247,9 +246,9 @@ class DeserializeRemoteExceptionTestCase(test_utils.BaseTestCase):
               args=[],
               kwargs={'foobar': 'blaa'},
               str=("Remote error: Exception test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               msg=("Remote error: Exception test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               remote_name='RemoteError',
               remote_args=(),
               remote_kwargs={'exc_type': 'Exception',
@@ -263,9 +262,9 @@ class DeserializeRemoteExceptionTestCase(test_utils.BaseTestCase):
               args=[],
               kwargs={},
               str=("Remote error: SystemExit test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               msg=("Remote error: SystemExit test\n"
-                   "[%r]." % u'traceback\ntraceback\n'),
+                   "[%r]." % 'traceback\ntraceback\n'),
               remote_name='RemoteError',
               remote_args=(),
               remote_kwargs={'exc_type': 'SystemExit',
@@ -289,9 +288,9 @@ class DeserializeRemoteExceptionTestCase(test_utils.BaseTestCase):
 
         self.assertIsInstance(ex, self.cls)
         self.assertEqual(self.remote_name, ex.__class__.__name__)
-        self.assertEqual(self.str, six.text_type(ex))
+        self.assertEqual(self.str, str(ex))
         if hasattr(self, 'msg'):
-            self.assertEqual(self.msg, six.text_type(ex))
+            self.assertEqual(self.msg, str(ex))
             self.assertEqual((self.msg,) + self.remote_args, ex.args)
         else:
             self.assertEqual(self.remote_args, ex.args)
